@@ -487,7 +487,7 @@ my $opt = {
     'bindir'    => "/cw/bin",
     'probedir'  => "@libexecdir@/snmpdx",
     'probename' => "*",
-    'mibdir'    => "@datadir@/snmpdx", # FIXME
+    'mibdir'    => "@datadir@/snmpdx:@snmpmibdir@",
     'mibname'   => "snmpdx",
     'logfile'   => "@localstatedir@/snmpdx.log",
     'loglevel'  => 9,
